@@ -3,15 +3,23 @@ import os
 import re
 
 from celery import Celery
-from celery.task.control import revoke
 
 from .scrapers.manual import ManualControlScraper
 
 
+backend = "rpc://"
+if os.environ.get("AUTOSCRAPE_DB_HOST"):
+    backend = 'db+postgresql://%s:%s@%s/autoscrape' % (
+        os.environ["AUTOSCRAPE_DB_USER"],
+        os.environ["AUTOSCRAPE_DB_PASSWORD"],
+        os.environ["AUTOSCRAPE_DB_HOST"]
+    )
+
+
 app = Celery(
     'tasks',
     broker=os.environ.get("AUTOSCRAPE_RABBITMQ_HOST"),
-    backend='rpc://'
+    backend=backend,
 )
 
 app.conf.update(
@@ -38,9 +46,3 @@ def start(self, baseurl, args):
         args["output"] = output
     scraper = ManualControlScraper(baseurl, **args)
     scraper.run()
-
-
-@app.task(bind=True)
-def stop(self, id):
-    print("Stopping AutoScrape job: %s" % id)
-    revoke(id, terminate=True)  # , signal='SIGKILL')
